pub enum ProgressEvent<'a> {
DownloadStarted {
url: &'a Url,
total_bytes: Option<u64>,
},
DownloadProgress {
url: &'a Url,
bytes: u64,
total_bytes: Option<u64>,
},
DownloadComplete {
url: &'a Url,
},
ExtractStarted {
path: &'a Path,
total_bytes: Option<u64>,
},
ExtractProgress {
path: &'a Path,
bytes: u64,
total_bytes: Option<u64>,
},
ExtractComplete {
path: &'a Path,
},
}Expand description
Progress event emitted during download and extraction operations.
Variants
DownloadStarted
An HTTP download has started.
Fields
DownloadProgress
Bytes have been received.
Fields
DownloadComplete
An HTTP download has completed.
ExtractStarted
Extraction of a file from an archive has started.
Fields
ExtractProgress
Bytes have been extracted from an archive.
Fields
ExtractComplete
Extraction of a file from an archive has completed.