pub struct PackageIndex { /* private fields */ }Expand description
Parsed package index for one repository host across multiple dists.
Implementations
Sourceimpl PackageIndex
impl PackageIndex
Sourcepub fn new(
host: Url,
packages: IndexMap<String, IndexMap<String, UbuntuRepositoryEntry>>,
) -> Self
pub fn new( host: Url, packages: IndexMap<String, IndexMap<String, UbuntuRepositoryEntry>>, ) -> Self
Creates a new PackageIndex.
Sourcepub fn find(
&self,
query: &PackageQuery,
) -> Result<Option<&UbuntuRepositoryEntry>, UbuntuError>
pub fn find( &self, query: &PackageQuery, ) -> Result<Option<&UbuntuRepositoryEntry>, UbuntuError>
Looks up a package matching the query across all dists.
Returns the matching entry. Errors with PackageMultipleCandidates if
more than one dist contains a matching entry.
Sourcepub fn resolve_url(
&self,
entry: &UbuntuRepositoryEntry,
) -> Result<Url, UbuntuError>
pub fn resolve_url( &self, entry: &UbuntuRepositoryEntry, ) -> Result<Url, UbuntuError>
Resolves a package entry to its full download URL via this index’s host.