pub struct PackageQuery {
pub package: String,
pub version: String,
pub dbgsym: bool,
pub unsigned_fallback: bool,
}Expand description
Query parameters for looking up a package across all dists in an index.
Fields
package: StringDebian package name to match.
version: StringExact Version: field to match.
dbgsym: boolIf true, applies the dbgsym filter (no Depends field).
unsigned_fallback: boolIf true and the primary package name is not found, retries with the
linux-image-unsigned-* form (the linux-image- prefix is replaced
with linux-image-unsigned-).